
# Slot: nutrient of


holds between a one or more chemical substances present in food, irrespective of nutritional value (i.e. could also be a contaminant or additive)

URI: [biolink:nutrient_of](https://w3id.org/biolink/vocab/nutrient_of)


## Domain and Range

[ChemicalSubstance](ChemicalSubstance.md) &#8594;  <sub>0..\*</sub> [ChemicalSubstance](ChemicalSubstance.md)

## Parents

 *  is_a: [food component of](food_component_of.md)

## Children


## Used by


## Other properties

|  |  |  |
| --- | --- | --- |
| **In Subsets:** | | translator_minimal |

